protocols.dao.DaoFactoryBase

A base for Data Access Objects (DAO) Factory protocols.

Usage

protocols.dao.DaoFactoryBase()

Classes

Name Description
IdFieldNotFoundError Raised when the dto_model did not contain the expected id_field.
IdTypeNotSupportedError Raised when the id_field of the dto_model has an unexpected Type.
IndexFieldsInvalidError Raised when providing an invalid list of fields to index.

IdFieldNotFoundError

Raised when the dto_model did not contain the expected id_field.

Usage

IdFieldNotFoundError()


IdTypeNotSupportedError

Raised when the id_field of the dto_model has an unexpected Type.

Usage

IdTypeNotSupportedError()


IndexFieldsInvalidError

Raised when providing an invalid list of fields to index.

Usage

IndexFieldsInvalidError()