protocols.dao.UniqueConstraintViolationError

Raised when attempting to insert a resource violated a uniqueness constraint.

Usage

protocols.dao.UniqueConstraintViolationError(
    *,
    unique_fields,
)

This does not apply to the default unique index automatically applied to the ID field.