protocols.objstorage.PresignedPostURL
Container for presigned POST URLs along with additional metadata fields that
Usage
protocols.objstorage.PresignedPostURL()should be attached as body data when sending the POST request.
Container for presigned POST URLs along with additional metadata fields that
Usage
should be attached as body data when sending the POST request.