providers.akafka.ComboTranslator

Takes a list of translators implementing either the DaoSubscriberProtocol,

Usage

providers.akafka.ComboTranslator()

EventSubscriberProtocol, or both, and create a single translator implementing the EventSubscriberProtocol. This basically bundles the passed-in translators, with the resulting combo translator acting as a router that directs the event information to the appropriate translator based on its topic and type.