providers.mongodb.migrations.helpers.convert_persistent_event_v6()

Convert a persistent event document to the format expected by hexkit v6.

Usage

providers.mongodb.migrations.helpers.convert_persistent_event_v6(doc)

This will: - convert correlation_id to UUID - convert created to UTC datetime with milliseconds precision - populate event_id with UUID

If you need to modify other fields, you must define that logic separately.