providers.mongodb.migrations.helpers.convert_uuids_and_datetimes_v6()

Produce a function to convert a document to the format expected by hexkit v6.

Usage

providers.mongodb.migrations.helpers.convert_uuids_and_datetimes_v6(
    *, uuid_fields=None, date_fields=None
)

If uuid_fields is provided, it will convert those fields from string to UUID. If date_fields is provided, it will convert those fields from isoformat strings to UTC datetime objects with the microseconds rounded to milliseconds.

Parameters

uuid_fields: list[str] | None = None

List of fields currently storing UUIDs in string format.

date_fields: list[str] | None = None
List of fields currently storing datetimes as isoformat strings.