providers.redis.RedisBytesKeyValueStore
Redis-specific KVStore provider for binary (bytes) data.
Usage
providers.redis.RedisBytesKeyValueStore()Since Redis natively stores bytes, this is the most direct mapping with identity transformations.
Redis-specific KVStore provider for binary (bytes) data.
Usage
Since Redis natively stores bytes, this is the most direct mapping with identity transformations.