providers.s3.S3Config
S3-specific config params.
Usage
providers.s3.S3Config()Inherit your config class from this class if you need to talk to an S3 service in the backend.
S3-specific config params.
Usage
Inherit your config class from this class if you need to talk to an S3 service in the backend.