providers.s3.S3DtoKeyValueStore

S3-specific KVStore provider for Pydantic model (DTO) data.

Usage

providers.s3.S3DtoKeyValueStore(
    *, config, dto_model, bucket_id=DEFAULT_KV_BUCKET_ID
)

This store allows arbitrary DTOs (Pydantic models) to be stored as values, with the DTO model passed in the constructor.

Methods

Name Description
__init__() Initialize the provider with configuration, model type, and bucket name.

__init__()

Initialize the provider with configuration, model type, and bucket name.

Usage

__init__(*, config, dto_model, bucket_id=DEFAULT_KV_BUCKET_ID)
Parameters
config: S3Config

S3-specific config parameters.

dto_model: type[Dto]

The Pydantic model type to support for values.

bucket_id: str = DEFAULT_KV_BUCKET_ID
Name of the existing S3 bucket to hold the key-value pairs. Defaults to ‘kvstore’.