providers.s3.S3ObjectStorage

S3-based provider implementing the ObjectStorageProtocol.

Usage

providers.s3.S3ObjectStorage()

Methods

Name Description
__init__() Initialize with parameters needed to connect to the S3 storage

__init__()

Initialize with parameters needed to connect to the S3 storage

Usage

__init__(*, config)

The arguments are adapted from the boto3 library. Please have a look here for more descriptions: https://boto3.amazonaws.com/v1/documentation/api/latest/reference/core/session.html#boto3.session.Session.client

Parameters
config: S3Config
Config parameters specified using the S3Config model.