providers.vault.VaultConfig

Configuration parameters for connecting to a HashiCorp Vault server.

Usage

providers.vault.VaultConfig()

Inherit your config class from this class if your application uses Vault. At least one authentication method must be configured (AppRole or Kubernetes).

Methods

Name Description
validate_vault_ca() Check that the CA bundle can be read if it is specified.

validate_vault_ca()

Check that the CA bundle can be read if it is specified.

Usage

validate_vault_ca(value)