base.InboundProviderBase
Base class that should be used by inbound providers.
Usage
base.InboundProviderBase()Methods
| Name | Description |
|---|---|
| run() | Runs the inbound provider. Typically, it blocks forever. |
run()
Runs the inbound provider. Typically, it blocks forever.
Usage
run(forever=True)However, you can set forever to False to make it return after handling one operation.