log.configure_logging()
Set up logging.
Usage
log.configure_logging(
*,
config,
logger=None,
)Configures the root logger by default, but can be used to configure a specific logger as well. Will also log the complete configuration of the service with secret values hidden, if it’s passed to this function and inherits from LoggingConfig.