protocols.daopub.DaoPublisher
A Data Access Object (DAO) that automatically publishes changes according to the
Usage
protocols.daopub.DaoPublisher()outbox pattern.
Methods
| Name | Description |
|---|---|
| publish_pending() | Publishes all non-published changes. |
| republish() | Republishes the state of all resources independent of whether they have |
publish_pending()
Publishes all non-published changes.
Usage
publish_pending()
republish()
Republishes the state of all resources independent of whether they have
Usage
republish()already been published or not.