providers.mongodb.migrations.DbVersionMismatchError
Raised when the database is not at the version expected by the service.
Usage
providers.mongodb.migrations.DbVersionMismatchError()
Raised when the database is not at the version expected by the service.
Usage