providers.testing.InMemEventStore
A manager for multiple topics, whereby each topic is model as queue not as log.
Usage
providers.testing.InMemEventStore()It should be seen as a utility of the InMemEventPublisher and should only together with that class.
Methods
| Name | Description |
|---|---|
| __init__() | Create an in memory topic registry based on collections’ deque. |
| get() | Get the next element in the queue corresponding to the specified topic. |
| post() | Queue a new event to a topic. |
__init__()
Create an in memory topic registry based on collections’ deque.
Usage
__init__()
get()
Get the next element in the queue corresponding to the specified topic.
Usage
get(topic)
post()
Queue a new event to a topic.
Usage
post(topic, event)